@@ -1,4 +1,4 @@
-from baseClassifiers import Classifier
+from PyML.classifiers.baseClassifiers import Classifier
 
 class Template(Classifier) :
 
