@@ -5,6 +5,7 @@ from PyML.containers import ker
 from PyML.containers import parsers
 from PyML.utils import misc
 from PyML.containers.labels import Labels
+from PyML.datagen import sample
 
 class BaseDataSet (object) :
     """
@@ -29,6 +30,9 @@ class BaseDataSet (object) :
         # construct from a list or numpy array:
         elif (type(arg) == type([]) or type(arg) == numpy.ndarray) :
             self.fromArray(arg, **args)
+        # construct a dataset with no features; arg is the number of examples:
+        elif type(arg) == int :
+            self.makeEmpty(arg, **args)
         else:
             raise ValueError, 'wrong type of argument'
         if 'kernel' in args :
@@ -38,6 +42,13 @@ class BaseDataSet (object) :
         else :
             self.attachKernel('linear')
 
+    def __getitem__(self, index) :
+        if type(index) is list or type(index) is tuple or type(index) is numpy.ndarray :
+            return self.__class__(self, patterns = index)
+        else :
+            return self.getPattern(index)
+
+
     def setTrainingFunc(self, func) :
         #assert func is None or type(func).__name__ == 'function'
         self._trainingFunc = func
@@ -113,10 +124,8 @@ class BaseDataSet (object) :
         self.setTrainingFunc(other.trainingFunc)
         self.setTestingFunc(other.testingFunc)
 
-        deepcopy = True
-        if 'deepcopy' in args : deepcopy = args['deepcopy']
         # class dependent copying of data:
-        self.copy(other, patternsToCopy, deepcopy)
+        self.copy(other, patternsToCopy)
 
         self.attachKernel(other)
         self.attachLabels(Labels(other.labels,
@@ -141,13 +150,15 @@ class BaseDataSet (object) :
                 else :
                     setattr(self, attr, a)
 
-    def copy(self, other, patterns, deepcopy) :
+    def copy(self, other, patterns) :
         """
         Each class that wants to use the generic copy constructor needs
         to define this function for doing class-specific copying"""
 
         raise NotImplementedError
 
+    split = sample.split
+
     def getKernelMatrix(self) :
         """ 
         returns the kernel matrix as a numpy array
@@ -225,9 +236,9 @@ class BaseVectorDataSet (BaseDataSet) :
         parser = parsers.parserDispatcher(fileName, **args)
         # the DataSet container can only be used with a csv type file:
         if parser.__class__.__name__ == 'SparseParser' and \
-                self.__class__.__name__ == 'DataSet' :
+                self.__class__.__name__ != 'SparseDataSet' :
             raise ValueError, \
-                'cannot use a DataSet container with a sparse file'
+                'have to use a SparseDataSet container with a sparse file'
         parser.scan()
 
         self.initializeDataMatrix(len(parser), len(parser._featureID))
@@ -260,6 +271,31 @@ class BaseVectorDataSet (BaseDataSet) :
         else :
             self.attachLabels(Labels(L, patternID = patternID, **args))
 
+    def makeEmpty(self, size, **args) :
+
+        L = None
+        patternID = None
+        if 'labels' in args :
+            L = args['labels'].L[:]
+            patternID = args['labels'].patternID[:]
+        if 'L' in args :
+            L = args['L']
+        if 'patternID' in args :
+            patternID = args['patternID'][:]
+
+        if L is not None : assert size == len(L)                
+        if patternID is None :
+            patternID = [str(i) for i in range(1, size + 1)]
+
+        self.initializeDataMatrix(size, 0)
+
+        if 'labelsFile' in args :
+            self.attachLabels(Labels(args['labelsFile'], **args))
+        else :
+            args['patternID'] = patternID
+            self.attachLabels(Labels(L, **args))
+        
+
     def fromArray(self, X, **args) :
 
         L = None
@@ -274,7 +310,7 @@ class BaseVectorDataSet (BaseDataSet) :
             patternID = args['patternID'][:]
         if 'featureID' in args :
             if self.__class__.__name__ == 'SparseDataSet' :
-                raise vluaeError, 'cannot set feature ID for SparseDataSet'
+                raise ValueError, 'cannot set feature ID for SparseDataSet'
             self.featureID = args['featureID'][:]
 
         if L is not None : assert len(X) == len(L)                
@@ -290,8 +326,8 @@ class BaseVectorDataSet (BaseDataSet) :
         if 'labelsFile' in args :
             self.attachLabels(Labels(args['labelsFile'], **args))
         else :
-            self.attachLabels(Labels(L, patternID=patternID))
-
+            args['patternID'] = patternID
+            self.attachLabels(Labels(L, **args))
 
     def fromArrayAdd(self, X) :
 
